==> ci-auto-update-phpboost-6.0.3.zip: phpboost_ynh/README_es.md <==
<!--
Este archivo README esta generado automaticamente<https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
No se debe editar a mano.
-->

# PHPBoost para Yunohost

[![Nivel de integración](https://dash.yunohost.org/integration/phpboost.svg)](https://dash.yunohost.org/appci/app/phpboost) ![Estado funcional](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![Estado En Mantención](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![Instalar PHPBoost con Yunhost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[Leer este README en otros idiomas.](./ALL_README.md)*

> *Este paquete le permite instalarPHPBoost rapidamente y simplement en un servidor YunoHost.*  
> *Si no tiene YunoHost, visita [the guide](https://yunohost.org/install) para aprender como instalarla.*

## Descripción general

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**Versión actual:** 6.0.3~ynh1

**Demo:** <https://demo.phpboost.com/>

## Capturas

![Captura de PHPBoost](./doc/screenshots/screenshot.png)

## Documentaciones y recursos

- Sitio web oficial: <https://www.phpboost.com/>
- Documentación administrador oficial: <https://www.phpboost.com/wiki/wiki.php>
- Repositorio del código fuente oficial de la aplicación : <https://github.com/PHPBoost/PHPBoost>
- Catálogo YunoHost: <https://apps.yunohost.org/app/phpboost>
- Reportar un error: <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## Información para desarrolladores

Por favor enviar sus correcciones a la [`branch testing`](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing

Para probar la rama `testing`, sigue asÍ:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
o
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**Mas informaciones sobre el empaquetado de aplicaciones:** <https://yunohost.org/packaging_apps>

==> ci-auto-update-phpboost-6.0.4.zip: phpboost_ynh/README_es.md <==
<!--
Este archivo README esta generado automaticamente<https://github.com/YunoHost/apps/tree/master/tools/readme_generator>
No se debe editar a mano.
-->

# PHPBoost para Yunohost

[![Nivel de integración](https://dash.yunohost.org/integration/phpboost.svg)](https://ci-apps.yunohost.org/ci/apps/phpboost/) ![Estado funcional](https://ci-apps.yunohost.org/ci/badges/phpboost.status.svg) ![Estado En Mantención](https://ci-apps.yunohost.org/ci/badges/phpboost.maintain.svg)

[![Instalar PHPBoost con Yunhost](https://install-app.yunohost.org/install-with-yunohost.svg)](https://install-app.yunohost.org/?app=phpboost)

*[Leer este README en otros idiomas.](./ALL_README.md)*

> *Este paquete le permite instalarPHPBoost rapidamente y simplement en un servidor YunoHost.*  
> *Si no tiene YunoHost, visita [the guide](https://yunohost.org/install) para aprender como instalarla.*

## Descripción general

PHPBoost allows everyone to create his own website without any particular knowledge required in webmastering.

**Versión actual:** phpboost-6.0.4~ynh1

**Demo:** <https://demo.phpboost.com/>

## Capturas

![Captura de PHPBoost](./doc/screenshots/screenshot.png)

## Documentaciones y recursos

- Sitio web oficial: <https://www.phpboost.com/>
- Documentación administrador oficial: <https://www.phpboost.com/wiki/wiki.php>
- Repositorio del código fuente oficial de la aplicación : <https://github.com/PHPBoost/PHPBoost>
- Catálogo YunoHost: <https://apps.yunohost.org/app/phpboost>
- Reportar un error: <https://github.com/YunoHost-Apps/phpboost_ynh/issues>

## Información para desarrolladores

Por favor enviar sus correcciones a la [`branch testing`](https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing

Para probar la rama `testing`, sigue asÍ:

```bash
sudo yunohost app install https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
o
sudo yunohost app upgrade phpboost -u https://github.com/YunoHost-Apps/phpboost_ynh/tree/testing --debug
```

**Mas informaciones sobre el empaquetado de aplicaciones:** <https://yunohost.org/packaging_apps>
